# hckr -  cli hack for developers
[![PyPI - Version](https://img.shields.io/pypi/v/hckr.svg)](https://pypi.org/project/hckr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hckr.svg)](https://pypi.org/project/hckr)
[![Build](https://github.com/pateash/hckr/actions/workflows/build.yml/badge.svg)](https://github.com/pateash/hckr/actions/workflows/build.yml)
[![Dependabot](https://github.com/pateash/hckr/actions/workflows/dependabot/dependabot-updates/badge.svg)](https://github.com/pateash/hckr/actions/workflows/dependabot/dependabot-updates)
[![CodeQL](https://github.com/pateash/hckr/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/pateash/hckr/actions/workflows/github-code-scanning/codeql)
[![codecov](https://codecov.io/gh/pateash/hckr/branch/main/graph/badge.svg)](https://codecov.io/gh/pateash/hckr)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/pateash/hckr)](https://github.com/pateash/hckr/graphs/commit-activity)
[![GitHub contributors](https://img.shields.io/github/contributors/pateash/hckr)](https://github.com/pateash/hckr/graphs/contributors)

## Introduction

**hckr** is a command line utililty for developers.
It is focused on facilitating the development of applications by helping devs to do required tasks through utilities provided to enhance efficiency.

## Supporting the project ⭐

If you feel awesome and want to support us in a small way, please consider starring and sharing the repo! This helps us get known and grow the community. 🙏

<img src="https://raw.githubusercontent.com/lusaxweb/vuesax/master/public/github-vuesax-star.gif" alt="vuesax-star" />


## Table of Contents

- [Installation](#installation)
- [License](#license)
- [Contributing](#contributing)
- [Sponsors](#sponsors)

## Installation

```console
pip install hckr
```

## License

`hckr` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Contributing
Please find contributing guide here [CONTRIBUTING.md](CONTRIBUTING.md)

## Sponsors
> Built using Jetbrains Products
![Jetbrains](https://www.jetbrains.com/company/brand/img/jetbrains_logo.png)
